create table Account_ (
	mvccVersion bigint default 0 not null,
	accountId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	parentAccountId bigint,
	name nvarchar(75) null,
	legalName nvarchar(75) null,
	legalId nvarchar(75) null,
	legalType nvarchar(75) null,
	sicCode nvarchar(75) null,
	tickerSymbol nvarchar(75) null,
	industry nvarchar(75) null,
	type_ nvarchar(75) null,
	size_ nvarchar(75) null
);

create table Address (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	addressId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	classPK bigint,
	street1 nvarchar(75) null,
	street2 nvarchar(75) null,
	street3 nvarchar(75) null,
	city nvarchar(75) null,
	zip nvarchar(75) null,
	regionId bigint,
	countryId bigint,
	typeId bigint,
	mailing bit,
	primary_ bit
);

create table AnnouncementsDelivery (
	deliveryId bigint not null primary key,
	companyId bigint,
	userId bigint,
	type_ nvarchar(75) null,
	email bit,
	sms bit,
	website bit
);

create table AnnouncementsEntry (
	uuid_ nvarchar(75) null,
	entryId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	classPK bigint,
	title nvarchar(75) null,
	content nvarchar(max) null,
	url nvarchar(4000) null,
	type_ nvarchar(75) null,
	displayDate datetime null,
	expirationDate datetime null,
	priority int,
	alert bit
);

create table AnnouncementsFlag (
	flagId bigint not null primary key,
	companyId bigint,
	userId bigint,
	createDate datetime null,
	entryId bigint,
	value int
);

create table AssetCategory (
	uuid_ nvarchar(75) null,
	categoryId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	parentCategoryId bigint,
	leftCategoryId bigint,
	rightCategoryId bigint,
	name nvarchar(75) null,
	title nvarchar(4000) null,
	description nvarchar(4000) null,
	vocabularyId bigint,
	lastPublishDate datetime null
);

create table AssetEntries_AssetCategories (
	companyId bigint not null,
	categoryId bigint not null,
	entryId bigint not null,
	primary key (categoryId, entryId)
);

create table AssetEntries_AssetTags (
	companyId bigint not null,
	entryId bigint not null,
	tagId bigint not null,
	primary key (entryId, tagId)
);

create table AssetEntry (
	entryId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	classPK bigint,
	classUuid nvarchar(75) null,
	classTypeId bigint,
	listable bit,
	visible bit,
	startDate datetime null,
	endDate datetime null,
	publishDate datetime null,
	expirationDate datetime null,
	mimeType nvarchar(75) null,
	title nvarchar(4000) null,
	description nvarchar(max) null,
	summary nvarchar(max) null,
	url nvarchar(4000) null,
	layoutUuid nvarchar(75) null,
	height int,
	width int,
	priority float,
	viewCount int
);

create table AssetLink (
	linkId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	entryId1 bigint,
	entryId2 bigint,
	type_ int,
	weight int
);

create table AssetTag (
	uuid_ nvarchar(75) null,
	tagId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	name nvarchar(75) null,
	assetCount int,
	lastPublishDate datetime null
);

create table AssetVocabulary (
	uuid_ nvarchar(75) null,
	vocabularyId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	name nvarchar(75) null,
	title nvarchar(4000) null,
	description nvarchar(4000) null,
	settings_ nvarchar(4000) null,
	lastPublishDate datetime null
);

create table BrowserTracker (
	mvccVersion bigint default 0 not null,
	browserTrackerId bigint not null primary key,
	companyId bigint,
	userId bigint,
	browserKey bigint
);

create table ClassName_ (
	mvccVersion bigint default 0 not null,
	classNameId bigint not null primary key,
	value nvarchar(200) null
);

create table ClusterGroup (
	mvccVersion bigint default 0 not null,
	clusterGroupId bigint not null primary key,
	name nvarchar(75) null,
	clusterNodeIds nvarchar(75) null,
	wholeCluster bit
);

create table Company (
	mvccVersion bigint default 0 not null,
	companyId bigint not null primary key,
	accountId bigint,
	webId nvarchar(75) null,
	key_ nvarchar(max) null,
	mx nvarchar(200) null,
	homeURL nvarchar(4000) null,
	logoId bigint,
	system bit,
	maxUsers int,
	active_ bit
);

create table Contact_ (
	mvccVersion bigint default 0 not null,
	contactId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	classPK bigint,
	accountId bigint,
	parentContactId bigint,
	emailAddress nvarchar(254) null,
	firstName nvarchar(75) null,
	middleName nvarchar(75) null,
	lastName nvarchar(75) null,
	prefixId bigint,
	suffixId bigint,
	male bit,
	birthday datetime null,
	smsSn nvarchar(75) null,
	facebookSn nvarchar(75) null,
	jabberSn nvarchar(75) null,
	skypeSn nvarchar(75) null,
	twitterSn nvarchar(75) null,
	employeeStatusId nvarchar(75) null,
	employeeNumber nvarchar(75) null,
	jobTitle nvarchar(100) null,
	jobClass nvarchar(75) null,
	hoursOfOperation nvarchar(75) null
);

create table Counter (
	name nvarchar(150) not null primary key,
	currentId bigint
);

create table Country (
	mvccVersion bigint default 0 not null,
	countryId bigint not null primary key,
	name nvarchar(75) null,
	a2 nvarchar(75) null,
	a3 nvarchar(75) null,
	number_ nvarchar(75) null,
	idd_ nvarchar(75) null,
	zipRequired bit,
	active_ bit
);

create table DLFileEntry (
	uuid_ nvarchar(75) null,
	fileEntryId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	classPK bigint,
	repositoryId bigint,
	folderId bigint,
	treePath nvarchar(4000) null,
	name nvarchar(255) null,
	fileName nvarchar(255) null,
	extension nvarchar(75) null,
	mimeType nvarchar(75) null,
	title nvarchar(255) null,
	description nvarchar(4000) null,
	extraSettings nvarchar(max) null,
	fileEntryTypeId bigint,
	version nvarchar(75) null,
	size_ bigint,
	readCount int,
	smallImageId bigint,
	largeImageId bigint,
	custom1ImageId bigint,
	custom2ImageId bigint,
	manualCheckInRequired bit,
	lastPublishDate datetime null
);

create table DLFileEntryMetadata (
	uuid_ nvarchar(75) null,
	fileEntryMetadataId bigint not null primary key,
	companyId bigint,
	DDMStorageId bigint,
	DDMStructureId bigint,
	fileEntryId bigint,
	fileVersionId bigint
);

create table DLFileEntryType (
	uuid_ nvarchar(75) null,
	fileEntryTypeId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	fileEntryTypeKey nvarchar(75) null,
	name nvarchar(4000) null,
	description nvarchar(4000) null,
	lastPublishDate datetime null
);

create table DLFileEntryTypes_DLFolders (
	companyId bigint not null,
	fileEntryTypeId bigint not null,
	folderId bigint not null,
	primary key (fileEntryTypeId, folderId)
);

create table DLFileShortcut (
	uuid_ nvarchar(75) null,
	fileShortcutId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	repositoryId bigint,
	folderId bigint,
	toFileEntryId bigint,
	treePath nvarchar(4000) null,
	active_ bit,
	lastPublishDate datetime null,
	status int,
	statusByUserId bigint,
	statusByUserName nvarchar(75) null,
	statusDate datetime null
);

create table DLFileVersion (
	uuid_ nvarchar(75) null,
	fileVersionId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	repositoryId bigint,
	folderId bigint,
	fileEntryId bigint,
	treePath nvarchar(4000) null,
	fileName nvarchar(255) null,
	extension nvarchar(75) null,
	mimeType nvarchar(75) null,
	title nvarchar(255) null,
	description nvarchar(4000) null,
	changeLog nvarchar(75) null,
	extraSettings nvarchar(max) null,
	fileEntryTypeId bigint,
	version nvarchar(75) null,
	size_ bigint,
	checksum nvarchar(75) null,
	lastPublishDate datetime null,
	status int,
	statusByUserId bigint,
	statusByUserName nvarchar(75) null,
	statusDate datetime null
);

create table DLFolder (
	uuid_ nvarchar(75) null,
	folderId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	repositoryId bigint,
	mountPoint bit,
	parentFolderId bigint,
	treePath nvarchar(4000) null,
	name nvarchar(255) null,
	description nvarchar(4000) null,
	lastPostDate datetime null,
	defaultFileEntryTypeId bigint,
	hidden_ bit,
	restrictionType int,
	lastPublishDate datetime null,
	status int,
	statusByUserId bigint,
	statusByUserName nvarchar(75) null,
	statusDate datetime null
);

create table EmailAddress (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	emailAddressId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	classPK bigint,
	address nvarchar(254) null,
	typeId bigint,
	primary_ bit
);

create table ExpandoColumn (
	columnId bigint not null primary key,
	companyId bigint,
	tableId bigint,
	name nvarchar(75) null,
	type_ int,
	defaultData nvarchar(max) null,
	typeSettings nvarchar(max) null
);

create table ExpandoRow (
	rowId_ bigint not null primary key,
	companyId bigint,
	modifiedDate datetime null,
	tableId bigint,
	classPK bigint
);

create table ExpandoTable (
	tableId bigint not null primary key,
	companyId bigint,
	classNameId bigint,
	name nvarchar(75) null
);

create table ExpandoValue (
	valueId bigint not null primary key,
	companyId bigint,
	tableId bigint,
	columnId bigint,
	rowId_ bigint,
	classNameId bigint,
	classPK bigint,
	data_ nvarchar(max) null
);

create table ExportImportConfiguration (
	mvccVersion bigint default 0 not null,
	exportImportConfigurationId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	name nvarchar(200) null,
	description nvarchar(4000) null,
	type_ int,
	settings_ nvarchar(max) null,
	status int,
	statusByUserId bigint,
	statusByUserName nvarchar(75) null,
	statusDate datetime null
);

create table Group_ (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	groupId bigint not null primary key,
	companyId bigint,
	creatorUserId bigint,
	classNameId bigint,
	classPK bigint,
	parentGroupId bigint,
	liveGroupId bigint,
	treePath nvarchar(4000) null,
	groupKey nvarchar(150) null,
	name nvarchar(4000) null,
	description nvarchar(4000) null,
	type_ int,
	typeSettings nvarchar(max) null,
	manualMembership bit,
	membershipRestriction int,
	friendlyURL nvarchar(255) null,
	site bit,
	remoteStagingGroupCount int,
	inheritContent bit,
	active_ bit
);

create table Groups_Orgs (
	companyId bigint not null,
	groupId bigint not null,
	organizationId bigint not null,
	primary key (groupId, organizationId)
);

create table Groups_Roles (
	companyId bigint not null,
	groupId bigint not null,
	roleId bigint not null,
	primary key (groupId, roleId)
);

create table Groups_UserGroups (
	companyId bigint not null,
	groupId bigint not null,
	userGroupId bigint not null,
	primary key (groupId, userGroupId)
);

create table Image (
	mvccVersion bigint default 0 not null,
	imageId bigint not null primary key,
	companyId bigint,
	modifiedDate datetime null,
	type_ nvarchar(75) null,
	height int,
	width int,
	size_ int
);

create table Layout (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	plid bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	privateLayout bit,
	layoutId bigint,
	parentLayoutId bigint,
	name nvarchar(4000) null,
	title nvarchar(4000) null,
	description nvarchar(4000) null,
	keywords nvarchar(4000) null,
	robots nvarchar(4000) null,
	type_ nvarchar(75) null,
	typeSettings nvarchar(max) null,
	hidden_ bit,
	friendlyURL nvarchar(255) null,
	iconImageId bigint,
	themeId nvarchar(75) null,
	colorSchemeId nvarchar(75) null,
	css nvarchar(max) null,
	priority int,
	layoutPrototypeUuid nvarchar(75) null,
	layoutPrototypeLinkEnabled bit,
	sourcePrototypeLayoutUuid nvarchar(75) null,
	lastPublishDate datetime null
);

create table LayoutBranch (
	mvccVersion bigint default 0 not null,
	layoutBranchId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	layoutSetBranchId bigint,
	plid bigint,
	name nvarchar(75) null,
	description nvarchar(4000) null,
	master bit
);

create table LayoutFriendlyURL (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	layoutFriendlyURLId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	plid bigint,
	privateLayout bit,
	friendlyURL nvarchar(255) null,
	languageId nvarchar(75) null,
	lastPublishDate datetime null
);

create table LayoutPrototype (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	layoutPrototypeId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	name nvarchar(max) null,
	description nvarchar(max) null,
	settings_ nvarchar(4000) null,
	active_ bit
);

create table LayoutRevision (
	mvccVersion bigint default 0 not null,
	layoutRevisionId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	layoutSetBranchId bigint,
	layoutBranchId bigint,
	parentLayoutRevisionId bigint,
	head bit,
	major bit,
	plid bigint,
	privateLayout bit,
	name nvarchar(4000) null,
	title nvarchar(4000) null,
	description nvarchar(4000) null,
	keywords nvarchar(4000) null,
	robots nvarchar(4000) null,
	typeSettings nvarchar(max) null,
	iconImageId bigint,
	themeId nvarchar(75) null,
	colorSchemeId nvarchar(75) null,
	css nvarchar(max) null,
	status int,
	statusByUserId bigint,
	statusByUserName nvarchar(75) null,
	statusDate datetime null
);

create table LayoutSet (
	mvccVersion bigint default 0 not null,
	layoutSetId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	createDate datetime null,
	modifiedDate datetime null,
	privateLayout bit,
	logoId bigint,
	themeId nvarchar(75) null,
	colorSchemeId nvarchar(75) null,
	css nvarchar(max) null,
	pageCount int,
	settings_ nvarchar(max) null,
	layoutSetPrototypeUuid nvarchar(75) null,
	layoutSetPrototypeLinkEnabled bit
);

create table LayoutSetBranch (
	mvccVersion bigint default 0 not null,
	layoutSetBranchId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	privateLayout bit,
	name nvarchar(75) null,
	description nvarchar(4000) null,
	master bit,
	logoId bigint,
	themeId nvarchar(75) null,
	colorSchemeId nvarchar(75) null,
	css nvarchar(max) null,
	settings_ nvarchar(max) null,
	layoutSetPrototypeUuid nvarchar(75) null,
	layoutSetPrototypeLinkEnabled bit
);

create table LayoutSetPrototype (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	layoutSetPrototypeId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	name nvarchar(4000) null,
	description nvarchar(4000) null,
	settings_ nvarchar(4000) null,
	active_ bit
);

create table ListType (
	mvccVersion bigint default 0 not null,
	listTypeId bigint not null primary key,
	name nvarchar(75) null,
	type_ nvarchar(75) null
);

create table MembershipRequest (
	mvccVersion bigint default 0 not null,
	membershipRequestId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	createDate datetime null,
	comments nvarchar(4000) null,
	replyComments nvarchar(4000) null,
	replyDate datetime null,
	replierUserId bigint,
	statusId bigint
);

create table Organization_ (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	organizationId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	parentOrganizationId bigint,
	treePath nvarchar(4000) null,
	name nvarchar(100) null,
	type_ nvarchar(75) null,
	recursable bit,
	regionId bigint,
	countryId bigint,
	statusId bigint,
	comments nvarchar(4000) null,
	logoId bigint
);

create table OrgGroupRole (
	mvccVersion bigint default 0 not null,
	organizationId bigint not null,
	groupId bigint not null,
	roleId bigint not null,
	companyId bigint,
	primary key (organizationId, groupId, roleId)
);

create table OrgLabor (
	mvccVersion bigint default 0 not null,
	orgLaborId bigint not null primary key,
	companyId bigint,
	organizationId bigint,
	typeId bigint,
	sunOpen int,
	sunClose int,
	monOpen int,
	monClose int,
	tueOpen int,
	tueClose int,
	wedOpen int,
	wedClose int,
	thuOpen int,
	thuClose int,
	friOpen int,
	friClose int,
	satOpen int,
	satClose int
);

create table PasswordPolicy (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	passwordPolicyId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	defaultPolicy bit,
	name nvarchar(75) null,
	description nvarchar(4000) null,
	changeable bit,
	changeRequired bit,
	minAge bigint,
	checkSyntax bit,
	allowDictionaryWords bit,
	minAlphanumeric int,
	minLength int,
	minLowerCase int,
	minNumbers int,
	minSymbols int,
	minUpperCase int,
	regex nvarchar(75) null,
	history bit,
	historyCount int,
	expireable bit,
	maxAge bigint,
	warningTime bigint,
	graceLimit int,
	lockout bit,
	maxFailure int,
	lockoutDuration bigint,
	requireUnlock bit,
	resetFailureCount bigint,
	resetTicketMaxAge bigint
);

create table PasswordPolicyRel (
	mvccVersion bigint default 0 not null,
	passwordPolicyRelId bigint not null primary key,
	companyId bigint,
	passwordPolicyId bigint,
	classNameId bigint,
	classPK bigint
);

create table PasswordTracker (
	mvccVersion bigint default 0 not null,
	passwordTrackerId bigint not null primary key,
	companyId bigint,
	userId bigint,
	createDate datetime null,
	password_ nvarchar(75) null
);

create table Phone (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	phoneId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	classPK bigint,
	number_ nvarchar(75) null,
	extension nvarchar(75) null,
	typeId bigint,
	primary_ bit
);

create table PluginSetting (
	mvccVersion bigint default 0 not null,
	pluginSettingId bigint not null primary key,
	companyId bigint,
	pluginId nvarchar(75) null,
	pluginType nvarchar(75) null,
	roles nvarchar(4000) null,
	active_ bit
);

create table PortalPreferences (
	mvccVersion bigint default 0 not null,
	portalPreferencesId bigint not null primary key,
	ownerId bigint,
	ownerType int,
	preferences nvarchar(max) null
);

create table Portlet (
	mvccVersion bigint default 0 not null,
	id_ bigint not null primary key,
	companyId bigint,
	portletId nvarchar(200) null,
	roles nvarchar(4000) null,
	active_ bit
);

create table PortletItem (
	mvccVersion bigint default 0 not null,
	portletItemId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	name nvarchar(75) null,
	portletId nvarchar(200) null,
	classNameId bigint
);

create table PortletPreferences (
	mvccVersion bigint default 0 not null,
	portletPreferencesId bigint not null primary key,
	companyId bigint,
	ownerId bigint,
	ownerType int,
	plid bigint,
	portletId nvarchar(200) null,
	preferences nvarchar(max) null
);

create table RatingsEntry (
	uuid_ nvarchar(75) null,
	entryId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	classPK bigint,
	score float
);

create table RatingsStats (
	statsId bigint not null primary key,
	companyId bigint,
	classNameId bigint,
	classPK bigint,
	totalEntries int,
	totalScore float,
	averageScore float
);

create table RecentLayoutBranch (
	mvccVersion bigint default 0 not null,
	recentLayoutBranchId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	layoutBranchId bigint,
	layoutSetBranchId bigint,
	plid bigint
);

create table RecentLayoutRevision (
	mvccVersion bigint default 0 not null,
	recentLayoutRevisionId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	layoutRevisionId bigint,
	layoutSetBranchId bigint,
	plid bigint
);

create table RecentLayoutSetBranch (
	mvccVersion bigint default 0 not null,
	recentLayoutSetBranchId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	layoutSetBranchId bigint,
	layoutSetId bigint
);

create table Region (
	mvccVersion bigint default 0 not null,
	regionId bigint not null primary key,
	countryId bigint,
	regionCode nvarchar(75) null,
	name nvarchar(75) null,
	active_ bit
);

create table Release_ (
	mvccVersion bigint default 0 not null,
	releaseId bigint not null primary key,
	createDate datetime null,
	modifiedDate datetime null,
	servletContextName nvarchar(75) null,
	schemaVersion nvarchar(75) null,
	buildNumber int,
	buildDate datetime null,
	verified bit,
	state_ int,
	testString nvarchar(1024) null
);

create table Repository (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	repositoryId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	name nvarchar(200) null,
	description nvarchar(4000) null,
	portletId nvarchar(200) null,
	typeSettings nvarchar(max) null,
	dlFolderId bigint,
	lastPublishDate datetime null
);

create table RepositoryEntry (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	repositoryEntryId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	repositoryId bigint,
	mappedId nvarchar(255) null,
	manualCheckInRequired bit,
	lastPublishDate datetime null
);

create table ResourceAction (
	mvccVersion bigint default 0 not null,
	resourceActionId bigint not null primary key,
	name nvarchar(255) null,
	actionId nvarchar(75) null,
	bitwiseValue bigint
);

create table ResourceBlock (
	mvccVersion bigint default 0 not null,
	resourceBlockId bigint not null primary key,
	companyId bigint,
	groupId bigint,
	name nvarchar(75) null,
	permissionsHash nvarchar(75) null,
	referenceCount bigint
);

create table ResourceBlockPermission (
	mvccVersion bigint default 0 not null,
	resourceBlockPermissionId bigint not null primary key,
	companyId bigint,
	resourceBlockId bigint,
	roleId bigint,
	actionIds bigint
);

create table ResourcePermission (
	mvccVersion bigint default 0 not null,
	resourcePermissionId bigint not null primary key,
	companyId bigint,
	name nvarchar(255) null,
	scope int,
	primKey nvarchar(255) null,
	primKeyId bigint,
	roleId bigint,
	ownerId bigint,
	actionIds bigint,
	viewActionId bit
);

create table ResourceTypePermission (
	mvccVersion bigint default 0 not null,
	resourceTypePermissionId bigint not null primary key,
	companyId bigint,
	groupId bigint,
	name nvarchar(75) null,
	roleId bigint,
	actionIds bigint
);

create table Role_ (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	roleId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	classPK bigint,
	name nvarchar(75) null,
	title nvarchar(4000) null,
	description nvarchar(4000) null,
	type_ int,
	subtype nvarchar(75) null
);

create table ServiceComponent (
	mvccVersion bigint default 0 not null,
	serviceComponentId bigint not null primary key,
	buildNamespace nvarchar(75) null,
	buildNumber bigint,
	buildDate bigint,
	data_ nvarchar(max) null
);

create table SocialActivity (
	activityId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	createDate bigint,
	activitySetId bigint,
	mirrorActivityId bigint,
	classNameId bigint,
	classPK bigint,
	parentClassNameId bigint,
	parentClassPK bigint,
	type_ int,
	extraData nvarchar(4000) null,
	receiverUserId bigint
);

create table SocialActivityAchievement (
	activityAchievementId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	createDate bigint,
	name nvarchar(75) null,
	firstInGroup bit
);

create table SocialActivityCounter (
	activityCounterId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	classNameId bigint,
	classPK bigint,
	name nvarchar(75) null,
	ownerType int,
	currentValue int,
	totalValue int,
	graceValue int,
	startPeriod int,
	endPeriod int,
	active_ bit
);

create table SocialActivityLimit (
	activityLimitId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	classNameId bigint,
	classPK bigint,
	activityType int,
	activityCounterName nvarchar(75) null,
	value nvarchar(75) null
);

create table SocialActivitySet (
	activitySetId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	createDate bigint,
	modifiedDate bigint,
	classNameId bigint,
	classPK bigint,
	type_ int,
	extraData nvarchar(4000) null,
	activityCount int
);

create table SocialActivitySetting (
	activitySettingId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	classNameId bigint,
	activityType int,
	name nvarchar(75) null,
	value nvarchar(1024) null
);

create table SocialRelation (
	uuid_ nvarchar(75) null,
	relationId bigint not null primary key,
	companyId bigint,
	createDate bigint,
	userId1 bigint,
	userId2 bigint,
	type_ int
);

create table SocialRequest (
	uuid_ nvarchar(75) null,
	requestId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	createDate bigint,
	modifiedDate bigint,
	classNameId bigint,
	classPK bigint,
	type_ int,
	extraData nvarchar(4000) null,
	receiverUserId bigint,
	status int
);

create table SystemEvent (
	mvccVersion bigint default 0 not null,
	systemEventId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	classNameId bigint,
	classPK bigint,
	classUuid nvarchar(75) null,
	referrerClassNameId bigint,
	parentSystemEventId bigint,
	systemEventSetKey bigint,
	type_ int,
	extraData nvarchar(max) null
);

create table Team (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	teamId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	groupId bigint,
	name nvarchar(75) null,
	description nvarchar(4000) null,
	lastPublishDate datetime null
);

create table Ticket (
	mvccVersion bigint default 0 not null,
	ticketId bigint not null primary key,
	companyId bigint,
	createDate datetime null,
	classNameId bigint,
	classPK bigint,
	key_ nvarchar(75) null,
	type_ int,
	extraInfo nvarchar(max) null,
	expirationDate datetime null
);

create table UserNotificationDelivery (
	mvccVersion bigint default 0 not null,
	userNotificationDeliveryId bigint not null primary key,
	companyId bigint,
	userId bigint,
	portletId nvarchar(200) null,
	classNameId bigint,
	notificationType int,
	deliveryType int,
	deliver bit
);

create table User_ (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	userId bigint not null primary key,
	companyId bigint,
	createDate datetime null,
	modifiedDate datetime null,
	defaultUser bit,
	contactId bigint,
	password_ nvarchar(75) null,
	passwordEncrypted bit,
	passwordReset bit,
	passwordModifiedDate datetime null,
	digest nvarchar(255) null,
	reminderQueryQuestion nvarchar(75) null,
	reminderQueryAnswer nvarchar(75) null,
	graceLoginCount int,
	screenName nvarchar(75) null,
	emailAddress nvarchar(254) null,
	facebookId bigint,
	googleUserId nvarchar(75) null,
	ldapServerId bigint,
	openId nvarchar(1024) null,
	portraitId bigint,
	languageId nvarchar(75) null,
	timeZoneId nvarchar(75) null,
	greeting nvarchar(255) null,
	comments nvarchar(4000) null,
	firstName nvarchar(75) null,
	middleName nvarchar(75) null,
	lastName nvarchar(75) null,
	jobTitle nvarchar(100) null,
	loginDate datetime null,
	loginIP nvarchar(75) null,
	lastLoginDate datetime null,
	lastLoginIP nvarchar(75) null,
	lastFailedLoginDate datetime null,
	failedLoginAttempts int,
	lockout bit,
	lockoutDate datetime null,
	agreedToTermsOfUse bit,
	emailAddressVerified bit,
	status int
);

create table UserGroup (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	userGroupId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	parentUserGroupId bigint,
	name nvarchar(75) null,
	description nvarchar(4000) null,
	addedByLDAPImport bit
);

create table UserGroupGroupRole (
	mvccVersion bigint default 0 not null,
	userGroupId bigint not null,
	groupId bigint not null,
	roleId bigint not null,
	companyId bigint,
	primary key (userGroupId, groupId, roleId)
);

create table UserGroupRole (
	mvccVersion bigint default 0 not null,
	userId bigint not null,
	groupId bigint not null,
	roleId bigint not null,
	companyId bigint,
	primary key (userId, groupId, roleId)
);

create table UserGroups_Teams (
	companyId bigint not null,
	teamId bigint not null,
	userGroupId bigint not null,
	primary key (teamId, userGroupId)
);

create table UserIdMapper (
	mvccVersion bigint default 0 not null,
	userIdMapperId bigint not null primary key,
	companyId bigint,
	userId bigint,
	type_ nvarchar(75) null,
	description nvarchar(75) null,
	externalUserId nvarchar(75) null
);

create table UserNotificationEvent (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	userNotificationEventId bigint not null primary key,
	companyId bigint,
	userId bigint,
	type_ nvarchar(200) null,
	timestamp bigint,
	deliveryType int,
	deliverBy bigint,
	delivered bit,
	payload nvarchar(max) null,
	actionRequired bit,
	archived bit
);

create table Users_Groups (
	companyId bigint not null,
	groupId bigint not null,
	userId bigint not null,
	primary key (groupId, userId)
);

create table Users_Orgs (
	companyId bigint not null,
	organizationId bigint not null,
	userId bigint not null,
	primary key (organizationId, userId)
);

create table Users_Roles (
	companyId bigint not null,
	roleId bigint not null,
	userId bigint not null,
	primary key (roleId, userId)
);

create table Users_Teams (
	companyId bigint not null,
	teamId bigint not null,
	userId bigint not null,
	primary key (teamId, userId)
);

create table Users_UserGroups (
	companyId bigint not null,
	userId bigint not null,
	userGroupId bigint not null,
	primary key (userId, userGroupId)
);

create table UserTracker (
	mvccVersion bigint default 0 not null,
	userTrackerId bigint not null primary key,
	companyId bigint,
	userId bigint,
	modifiedDate datetime null,
	sessionId nvarchar(200) null,
	remoteAddr nvarchar(75) null,
	remoteHost nvarchar(75) null,
	userAgent nvarchar(200) null
);

create table UserTrackerPath (
	mvccVersion bigint default 0 not null,
	userTrackerPathId bigint not null primary key,
	companyId bigint,
	userTrackerId bigint,
	path_ nvarchar(4000) null,
	pathDate datetime null
);

create table VirtualHost (
	mvccVersion bigint default 0 not null,
	virtualHostId bigint not null primary key,
	companyId bigint,
	layoutSetId bigint,
	hostname nvarchar(200) null
);

create table WebDAVProps (
	mvccVersion bigint default 0 not null,
	webDavPropsId bigint not null primary key,
	companyId bigint,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	classPK bigint,
	props nvarchar(max) null
);

create table Website (
	mvccVersion bigint default 0 not null,
	uuid_ nvarchar(75) null,
	websiteId bigint not null primary key,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	classPK bigint,
	url nvarchar(4000) null,
	typeId bigint,
	primary_ bit,
	lastPublishDate datetime null
);

create table WorkflowDefinitionLink (
	mvccVersion bigint default 0 not null,
	workflowDefinitionLinkId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	classPK bigint,
	typePK bigint,
	workflowDefinitionName nvarchar(75) null,
	workflowDefinitionVersion int
);

create table WorkflowInstanceLink (
	mvccVersion bigint default 0 not null,
	workflowInstanceLinkId bigint not null primary key,
	groupId bigint,
	companyId bigint,
	userId bigint,
	userName nvarchar(75) null,
	createDate datetime null,
	modifiedDate datetime null,
	classNameId bigint,
	classPK bigint,
	workflowInstanceId bigint
);
